@@ -6,7 +6,10 @@ from .api_call_with_price import ApiCallWithPrice
 from .api_call_with_price_results_page import ApiCallWithPriceResultsPage
 from .api_token import ApiToken
 from .api_token_results_page import ApiTokenResultsPage
+from .cluster import Cluster
 from .created_at_sort_mode import CreatedAtSortMode
+from .duration import Duration
+from .engine_metadata import EngineMetadata
 from .error import Error
 from .extended_user import ExtendedUser
 from .extended_user_results_page import ExtendedUserResultsPage
@@ -16,8 +19,19 @@ from .file_conversion_results_page import FileConversionResultsPage
 from .file_conversion_source_format import FileConversionSourceFormat
 from .file_conversion_status import FileConversionStatus
 from .file_conversion_with_output import FileConversionWithOutput
+from .file_system_metadata import FileSystemMetadata
+from .gateway import Gateway
+from .jetstream import Jetstream
+from .jetstream_api_stats import JetstreamApiStats
+from .jetstream_config import JetstreamConfig
+from .jetstream_stats import JetstreamStats
+from .leaf_node import LeafNode
+from .meta_cluster_info import MetaClusterInfo
+from .metadata import Metadata
 from .method import Method
+from .nats_connection import NatsConnection
 from .pong import Pong
+from .session import Session
 from .status_code import StatusCode
 from .user import User
 from .user_results_page import UserResultsPage
